@@ -74,7 +74,7 @@ Afdict_class * afdict_find(Dictionary afdict, const char * con, bool notify_err)
 	}
 	if (notify_err) {
 		prt_error("Warning: Unknown class name %s found near line %d of %s.\n"
-		          "\tThis class name will be ignored.",
+		          "\tThis class name will be ignored.\n",
 		          con, afdict->line_number, afdict->name);
 	}
 	return NULL;
@@ -109,7 +109,7 @@ static void load_affix(Dictionary afdict, Dict_node *dn, int l)
 			/* ??? should we support here more than one class? */
 			prt_error("Warning: Word \"%s\" found near line %d of %s.\n"
 			          "\tWord has more than one connector.\n"
-			          "\tThis word will be ignored.",
+			          "\tThis word will be ignored.\n",
 			          dn->string, afdict->line_number, afdict->name);
 			return;
 		}
@@ -302,7 +302,7 @@ static bool afdict_init(Dictionary dict)
 		affix_list_add(afdict, &afdict->afdict_class[AFDICT_INFIXMARK], "");
 	}
 
-	if (debug_level(+D_AI))
+	if (verbosity_level(+D_AI))
 	{
 		size_t l;
 
@@ -450,8 +450,8 @@ dictionary_six_str(const char * lang,
 		dict->spell_checker = spellcheck_create(dict->lang);
 #if defined HAVE_HUNSPELL || defined HAVE_ASPELL
 		/* FIXME: Move to spellcheck-*.c */
-		if (debug_level(D_USER_BASIC) && (NULL == dict->spell_checker))
-			prt_error("Info: %s: Spell checker disabled.", dict->lang);
+		if (verbosity_level(D_USER_BASIC) && (NULL == dict->spell_checker))
+			prt_error("Info: %s: Spell checker disabled.\n", dict->lang);
 #endif
 		dict->insert_entry = insert_list;
 
@@ -530,7 +530,7 @@ dictionary_six_str(const char * lang,
 	{
 		dict->locale = setlocale(LC_CTYPE, NULL);
 		prt_error("Warning: Couldn't set dictionary locale! "
-		          "Using current program locale \"%s\"", dict->locale);
+		          "Using current program locale \"%s\"\n", dict->locale);
 	}
 
 	/* setlocale() returns a string owned by the system. Copy it. */
@@ -556,7 +556,7 @@ dictionary_six_str(const char * lang,
 	dict->affix_table = dictionary_six(lang, affix_name, NULL, NULL, NULL, NULL);
 	if (dict->affix_table == NULL)
 	{
-		prt_error("Error: Could not open affix file %s", affix_name);
+		prt_error("Error: Could not open affix file %s\n", affix_name);
 		goto failure;
 	}
 	if (! afdict_init(dict))
@@ -580,7 +580,7 @@ dictionary_six_str(const char * lang,
 		goto failure;
 	}
 	locale = setlocale(LC_CTYPE, locale);            /* Restore the locale. */
-	assert(NULL != locale, "Cannot restore program locale\n");
+	assert(NULL != locale, "Cannot restore program locale");
 
 #ifdef USE_CORPUS
 	dict->corpus = lg_corpus_new();
@@ -599,6 +599,10 @@ dictionary_six_str(const char * lang,
 	dict->unknown_word_defined = boolean_dictionary_lookup(dict, UNKNOWN_WORD);
 	dict->use_unknown_word = true;
 
+	dict->shuffle_linkages = false;
+	if (0 == strcmp(dict->lang, "any") || NULL != dict->anysplit)
+		dict->shuffle_linkages = true;
+
 	dict_node = dictionary_lookup_list(dict, UNLIMITED_CONNECTORS_WORD);
 	if (dict_node != NULL)
 		dict->unlimited_connector_set = connector_set_create(dict_node->exp);
@@ -625,7 +629,7 @@ dictionary_six(const char * lang, const char * dict_name,
 	char* input = get_file_contents(dict_name);
 	if (NULL == input)
 	{
-		prt_error("Error: Could not open dictionary %s", dict_name);
+		prt_error("Error: Could not open dictionary \"%s\"\n", dict_name);
 		return NULL;
 	}
 
@@ -666,7 +670,7 @@ Dictionary dictionary_create_from_file(const char * lang)
 	}
 	else
 	{
-		prt_error("Error: No language specified!");
+		prt_error("Error: No language specified!\n");
 		dictionary = NULL;
 	}
 
