@@ -262,7 +262,7 @@ static void put_into_match_table(unsigned int size, Match_node ** t,
 	m->d = d;
 
 	xl = get_match_table_entry(size, t, c, dir);
-	assert(NULL != xl, "get_match_table_entry: Overflow\n");
+	assert(NULL != xl, "get_match_table_entry: Overflow");
 	if (dir == 1) {
 		*xl = add_to_right_table_list(m, *xl);
 	}
@@ -381,7 +381,7 @@ static void print_match_list(fast_matcher_t *ctxt, int id, size_t mlb, int w,
                              Connector *lc, int lw,
                              Connector *rc, int rw)
 {
-	if (!debug_level(9)) return;
+	if (!verbosity_level(9)) return;
 	Disjunct **m = &ctxt->match_list[mlb];
 
 	for (; NULL != *m; m++)
