@@ -224,9 +224,9 @@ void remove_empty_words(Linkage lkg)
 	Disjunct **cdj = lkg->chosen_disjuncts;
 	int *remap = alloca(lkg->num_words * sizeof(*remap));
 
-	if (debug_level(+D_REE))
+	if (verbosity_level(+D_REE))
 	{
-		printf("Info: chosen_disjuncts before:\n");
+		err_msg(lg_Debug, "chosen_disjuncts before:\n\\");
 		print_chosen_disjuncts_words(lkg);
 	}
 
@@ -246,9 +246,9 @@ void remove_empty_words(Linkage lkg)
 	lkg->num_words = j;
 	/* Unused memory not freed - all of it will be freed in free_linkages(). */
 
-	if (debug_level(+D_REE))
+	if (verbosity_level(+D_REE))
 	{
-		printf("Info: chosen_disjuncts after:\n");
+		err_msg(lg_Debug, "chosen_disjuncts after:\n\\");
 		print_chosen_disjuncts_words(lkg);
 	}
 
